@@ -23,8 +23,8 @@ log = logging.getLogger(__name__)
 
 
 class PipelineSchema(object):
-    """ Class to generate a schema object with
-    functions to handle pipeline JSON Schema """
+    """Class to generate a schema object with
+    functions to handle pipeline JSON Schema"""
 
     def __init__(self):
         """ Initialise the object """
@@ -79,13 +79,13 @@ class PipelineSchema(object):
             self.load_schema()
             num_params = self.validate_schema()
             self.get_schema_defaults()
-            log.info("[green][[✓]] Pipeline schema looks valid[/] [dim](found {} params)".format(num_params))
+            log.info("[green]\[✓] Pipeline schema looks valid[/] [dim](found {} params)".format(num_params))
         except json.decoder.JSONDecodeError as e:
             error_msg = "[bold red]Could not parse schema JSON:[/] {}".format(e)
             log.error(error_msg)
             raise AssertionError(error_msg)
         except AssertionError as e:
-            error_msg = "[red][[✗]] Pipeline schema does not follow nf-core specs:\n {}".format(e)
+            error_msg = "[red]\[✗] Pipeline schema does not follow nf-core specs:\n {}".format(e)
             log.error(error_msg)
             raise AssertionError(error_msg)
 
@@ -127,7 +127,7 @@ class PipelineSchema(object):
             json.dump(self.schema, fh, indent=4)
 
     def load_input_params(self, params_path):
-        """ Load a given a path to a parameters file (JSON/YAML)
+        """Load a given a path to a parameters file (JSON/YAML)
 
         These should be input parameters used to run a pipeline with
         the Nextflow -params-file option.
@@ -159,12 +159,12 @@ class PipelineSchema(object):
             assert self.schema is not None
             jsonschema.validate(self.input_params, self.schema)
         except AssertionError:
-            log.error("[red][[✗]] Pipeline schema not found")
+            log.error("[red]\[✗] Pipeline schema not found")
             return False
         except jsonschema.exceptions.ValidationError as e:
-            log.error("[red][[✗]] Input parameters are invalid: {}".format(e.message))
+            log.error("[red]\[✗] Input parameters are invalid: {}".format(e.message))
             return False
-        log.info("[green][[✓]] Input parameters look valid")
+        log.info("[green]\[✓] Input parameters look valid")
         return True
 
     def validate_schema(self, schema=None):
@@ -225,7 +225,7 @@ class PipelineSchema(object):
             return None
 
         assert "$schema" in self.schema, "Schema missing top-level `$schema` attribute"
-        schema_attr = "https://json-schema.org/draft-07/schema"
+        schema_attr = "http://json-schema.org/draft-07/schema"
         assert self.schema["$schema"] == schema_attr, "Schema `$schema` should be `{}`\n Found `{}`".format(
             schema_attr, self.schema["$schema"]
         )
